@@ -23,7 +23,7 @@ using namespace KUserFeedback::Console;
 class CategoryAggregationModelTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         Q_INIT_RESOURCE(schematemplates);
